.. highlight:: shell

============
Installation
============


Stable release
--------------

To install the SEAMM Forcefield Utilities, run this command in your terminal:

.. code-block:: console

   $ conda install -c conda-forge seamm-ff-util

This is the preferred method. If you wish, you can also install using `pip`_:

.. code-block:: console

    $ pip install seamm_ff_util

However, there may be issues with dependencies. It is safer to use Conda.

.. _pip: https://pip.pypa.io

From sources
------------

The sources for the seamm_ff_util can be downloaded
from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/molssi-seamm/seamm_ff_util

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/molssi-seamm/seamm_ff_util/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/molssi-seamm/seamm_ff_util
.. _tarball: https://github.com/molssi-seamm/seamm_ff_util/tarball/master
